# XPrompt common

xprompt client and server shared components

## publish common lib
1. bump version in `pyproject.toml`
2. `poetry build`
3. `poetry publish`
4. `git tag -a v0.1.0 -m "version 0.1.0"`
